!=============================================================================
! WCSLIB 8.5 - an implementation of the FITS WCS standard.
! Copyright (C) 1995-2025, Mark Calabretta
!
! This file is part of WCSLIB.
!
! WCSLIB is free software: you can redistribute it and/or modify it under the
! terms of the GNU Lesser General Public License as published by the Free
! Software Foundation, either version 3 of the License, or (at your option)
! any later version.
!
! WCSLIB is distributed in the hope that it will be useful, but WITHOUT ANY
! WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
! more details.
!
! You should have received a copy of the GNU Lesser General Public License
! along with WCSLIB.  If not, see http://www.gnu.org/licenses.
!
! Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
! http://www.atnf.csiro.au/people/Mark.Calabretta
! $Id: wcserr_bindc.f90,v 8.5 2025/12/06 13:47:41 mcalabre Exp $
!=============================================================================

INTEGER FUNCTION WCSERR_GTC (ERR, WHAT, VALUE)
  INTEGER :: ERR(*), WHAT
  CHARACTER :: VALUE(*)

  INTERFACE
    INTEGER(C_INT) FUNCTION WCSERR_GTC_C (ERR, WHAT, VALUE) BIND (C)
      USE, INTRINSIC :: ISO_C_BINDING
      INTEGER(C_INT) :: ERR(*), WHAT
      CHARACTER(KIND=C_CHAR, LEN=1) :: VALUE(*)
    END FUNCTION WCSERR_GTC_C
  END INTERFACE

  WCSERR_GTC = WCSERR_GTC_C (ERR, WHAT, VALUE)
END FUNCTION WCSERR_GTC

!-----------------------------------------------------------------------------

INTEGER FUNCTION WCSERR_PRT (ERR, PREFIX)
  INTEGER :: ERR(*)
  CHARACTER :: PREFIX(*)

  INTERFACE
    INTEGER(C_INT) FUNCTION WCSERR_PRT_C (ERR, PREFIX) BIND (C)
      USE, INTRINSIC :: ISO_C_BINDING
      INTEGER(C_INT) :: ERR(*)
      CHARACTER(KIND=C_CHAR, LEN=1) :: PREFIX(72)
    END FUNCTION WCSERR_PRT_C
  END INTERFACE

  WCSERR_PRT = WCSERR_PRT_C (ERR, PREFIX)
END FUNCTION WCSERR_PRT
